@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2020  The Software Heritage developers
+# Copyright (C) 2017-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -77,6 +77,11 @@ class VaultBackend:
         self.storage = get_storage(**config["storage"])
         self.smtp_server = smtplib.SMTP(**config.get("smtp", {}))
 
+        if "db" not in self.config:
+            raise ValueError(
+                "The 'db' configuration entry is missing "
+                "in the vault configuration file"
+            )
         db_conn = config["db"]
         self._pool = psycopg2.pool.ThreadedConnectionPool(
             config.get("min_pool_conns", 1),
